

class InfoOverlay {
    constructor(graph) {
        this.graph = graph;
    }

    create() {
        const sceneNode = getCanvasDivNode();
        const overlayNode = document.createElement('div');
        overlayNode.id = 'infoOverlay'
        overlayNode.className = 'detail-view';
        //overlayNode.innerText = 'Hello there!';
        sceneNode.insertBefore(overlayNode, sceneNode.childNodes[2]);

        const close = document.createElement('div');
        close.innerHTML = '<p>&#10006;</p>';
        close.id = 'infoOverlayCloseButton';
        close.className = 'close-button';
        overlayNode.appendChild(close);

        const topArea = document.createElement('div');
        topArea.className = 'detail-view-top-area';
        overlayNode.appendChild(topArea);

        const nodeImage = document.createElement('img');
        nodeImage.id = 'infoOverlayImage';
        nodeImage.src = plugin_path + 'datasets/images/default.jpg';
        nodeImage.className = 'detail-view-image';
        topArea.appendChild(nodeImage);

        const headline = document.createElement('h2');
        headline.id = 'infoOverlayHeadline';
        headline.innerText = 'Default Text';
        headline.className = 'detail-view-headline';
        topArea.appendChild(headline);

        const textArea = document.createElement('div');
        textArea.className = 'detail-view-text-area';
        overlayNode.appendChild(textArea);

        const description = document.createElement('p');
        description.id = 'infoOverlayDescription';
        description.innerText = 'Default Text'
        description.setAttribute("overflow-y", "scroll");
        textArea.appendChild(description);

        const link_container = document.createElement('div');
        const links = document.createElement('div');
        const linkClasses = G.getLinkClasses();

        link_container.id = 'link_container';
        link_container.className = 'bottom container';
        links.className = 'tab';
        links.id = 'links';

        for(let i = 0; i < linkClasses.length; i++){

            const linkType = linkClasses[i];
            const tablink = document.createElement('button');
            tablink.className = 'tablinks';
            tablink.id = linkType + "_id";
            tablink.innerHTML = linkType[0] + linkType[1] + linkType[2];
            tablink.style = "background-color: " + this.graph.edgeColors[linkClasses[i]];
            tablink.setAttribute("onclick", "openTab(event, " + linkType + "_id)"); //unusual function call
            links.appendChild(tablink);

        }

        link_container.appendChild(links);

        for(let i = 0; i < linkClasses.length; i++){

            const linkType = linkClasses[i];
            const tabcontent = document.createElement('div');
            tabcontent.className = "tabcontent";
            tabcontent.id = linkType + "_id_content";
            tabcontent.style = "background-color: " + this.graph.edgeColors[linkClasses[i]];
            link_container.appendChild(tabcontent);

        }

        overlayNode.appendChild(link_container);

        jQuery('#infoOverlayCloseButton').click(function () {
            jQuery('#infoOverlay').slideUp('fast');
        });

        //sceneNode.appendChild(overlayNode);

    }

    updateInfoOverlay(node) {
        jQuery('#infoOverlayHeadline').text(node.name);
        if ('image' in node) {
            jQuery('#infoOverlayImage').attr('src', plugin_path + 'datasets/images/' + node.image);
        } else {
            jQuery('#infoOverlayImage').attr('src', plugin_path + 'datasets/images/default.jpg');
        }

        if ('description' in node) {
            jQuery('#infoOverlayDescription').text(node.description);
        } else {
            jQuery('#infoOverlayDescription').text('Default Text');
        }

        this.updateTabs(node);

        jQuery('#infoOverlay').slideDown('fast');
    }

    updateTabs(node){
        //tabs of the links to other nodes:
        //delete old nodes from tabcontent
        const tabcontent = document.getElementsByClassName("tabcontent");
        for (let i = 0; i < tabcontent.length; i++) {
            while (tabcontent[i].firstChild){
                tabcontent[i].removeChild(tabcontent[i].lastChild);
            }
        }
        //add new nodes to tabcontent
        for (let i = 0; i < tabcontent.length; i++) {                                   //for every type of link
            node.links.forEach(link => {                                            //and for every link
                if(link.type + '_id_content' == tabcontent[i].id){                  //is checked if the type is equal
                    const linkButton = document.createElement('div');      //and if so a new element is created
                    linkButton.className = "link img";
                    var node2;
                    if(link.source == node){
                        node2 = link.target;
                    }
                    else if(link.target == node){
                        node2 = link.source;
                    }
                    linkButton.id = "linkButton_" + node2.id;
                    const nodeID = node2.id;

                    const linkImage = document.createElement('img');
                    const linkTitle = document.createElement('div');

                    if ('image' in node2) {
                        linkImage.src = plugin_path + 'datasets/images/' + node2.image;
                    } else if(!('image' in node2) && ('id' in node2)) {
                        linkImage.src = plugin_path + 'datasets/images/default.jpg';
                    }

                    linkTitle.className = "link title";
                    linkTitle.innerHTML = node2.name;

                    //linkButton.appendChild(linkTitle);
                    linkButton.appendChild(linkImage);

                    jQuery(linkButton).on('click', () => this.graph.focusOnNode(nodeID));
                    tabcontent[i].appendChild(linkButton);
                }
            });
        }
    }



}

//is used in createInfoOverlay, as an unusual function call to open link-tabs
function openTab (event, tab) {
    var i, tabcontent, tablinks;

    // Get all elements with class="tabcontent" and hide them
    tabcontent = document.getElementsByClassName("tabcontent");
    for (i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

    // Get all elements with class="tablinks" and remove the class "active"
    tablinks = document.getElementsByClassName("tablinks");
    for (i = 0; i < tablinks.length; i++) {
        tablinks[i].className = tablinks[i].className.replace(" active", "");
    }

    // Show the current tab, and add an "active" class to the button that opened the tab
    document.getElementById(tab.id + "_content").style.display = "flex";
    event.currentTarget.className += " active";
}